pub fn write_patterns<W: Write>(w: &mut W, patterns: &Vec<Vec<Vec<bool>>>)Expand description
Write test patterns in Atalanta format
Each pattern may contain multiple timesteps. For each timestep, the value of each circuit input is given. The patterns are formatted as follows:
* This is a comment
* Input pattern with five input values set to zero
1: 00000
* The index increments at each pattern
2: 00000
* A pattern that contains three timesteps
3: 01110 00111 01000